use strict;
use warnings;
package Task::Tapper::Installer;
# git description: b339952cba4a4287921d8229e5672ce0b0f534df

BEGIN {
  $Task::Tapper::Installer::AUTHORITY = 'cpan:AMD';
}
{
  $Task::Tapper::Installer::VERSION = '0.001';
}
# ABSTRACT: Tapper - dependencies for machine installer


__END__
=pod

=head1 NAME

Task::Tapper::Installer - Tapper - dependencies for machine installer

=head1 VERSION

version 0.001

=head1 TASK CONTENTS

=head2 Tapper

=head3 L<Tapper::Remote>

=head3 L<Tapper::Installer>

1;

=head1 AUTHOR

AMD OSRC Tapper Team <tapper@amd64.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..

This is free software, licensed under:

  The (two-clause) FreeBSD License

=cut

